import codecs
import io
import sys

from story.adventures import BaseAdventure
from story.translation import gettext as _


class Adventure(BaseAdventure):

    title = _('Print method')

    def test(self, file):
        old_stdout = sys.stdout
        sys.stdout = io.StringIO()
        eval(codecs.open(file).read())
        message = sys.stdout.getvalue()
        sys.stdout = old_stdout
        assert message == _('Hi Python\n')



from story.story import BaseStory
from story.translation import gettext as _

from . import print_method


__author__ = """PySchool"""
__email__ = 'pyschool@sophilabs.co'
__version__ = '1.0.7'


class Story(BaseStory):

    name = 'hipyschool'
    title = _('Sample pyschool story.')
    adventures = [
        print_method
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

setup(
    name='hipyschool',
    version='1.0.7',
    description='A pyschool story for learning regular expressions.',
    long_description=readme + '\n\n' + history,
    author='Sophilabs',
    author_email='hi@sophilabs.co',
    url='https://github.com/pyschool/hipyschool',
    packages=['hipyschool'],
    entry_points={
        'console_scripts': [
            'hipyschool=hipyschool:Story.begin'
        ]
    },
    include_package_data=True,
    install_requires=[
        'story>=1.2.2'
    ],
    license='MIT license',
    zip_safe=False,
    keywords='hipyschool',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=[]
)
